==> knitrdata_0.4.1.tar.gz: knitrdata/NEWS.md <==
knitrdata 0.4.1
---------------------------------------------------------------------

- Fix to use radio buttons instead of checkboxes in addings
- Fix to avoid adding extra newline to decoded text files
- Implementation of gpg encoding in Rstudio addins

knitrdata 0.4.0
---------------------------------------------------------------------

- Added Rstudio addins for adding and removing data chunks

knitrdata 0.3.1
---------------------------------------------------------------------

- Added max.echo chunk option
- Added script for testing of large data chunks
- Fix for global assignment issue based on persistent data

knitrdata 0.3.0
---------------------------------------------------------------------

- Added md5sum checks on `data` chunks
- Added `create_chunk` and `insert_chunk` to facilitate placing chunks in Rmarkdown docs
- Added `list_rmd_chunks` and `splice_rmd_by_chunk` to facilitate removing and decoding `data` chunks
- Expanded README
- Vignette update for new features

knitrdata 0.2.1
---------------------------------------------------------------------

- Improving vignette and changing `eval=FALSE` functioning.
- Changing `newline` chunk option to `line.sep`.
- Fixing instructions regarding install with `remotes` to avoid missing vignettes problems.


knitrdata 0.2.0
---------------------------------------------------------------------

- Adding loader.function chunk option

knitrdata 0.1.0
---------------------------------------------------------------------

- Initial release

==> knitrdata_0.5.0.tar.gz: knitrdata/NEWS.md <==
knitrdata 0.5.0
---------------------------------------------------------------------

- Changing to insertText in Rstudio addins to speed insertion
- New non-interactive addin to create empty data chunk
- Better handling of missing password for GPG-encrypted chunks during knit
- knitrdata instructional video

knitrdata 0.4.1
---------------------------------------------------------------------

- Fix to use radio buttons instead of checkboxes in addings
- Fix to avoid adding extra newline to decoded text files
- Implementation of gpg encoding in Rstudio addins

knitrdata 0.4.0
---------------------------------------------------------------------

- Added Rstudio addins for adding and removing data chunks

knitrdata 0.3.1
---------------------------------------------------------------------

- Added max.echo chunk option
- Added script for testing of large data chunks
- Fix for global assignment issue based on persistent data

knitrdata 0.3.0
---------------------------------------------------------------------

- Added md5sum checks on `data` chunks
- Added `create_chunk` and `insert_chunk` to facilitate placing chunks in Rmarkdown docs
- Added `list_rmd_chunks` and `splice_rmd_by_chunk` to facilitate removing and decoding `data` chunks
- Expanded README
- Vignette update for new features

knitrdata 0.2.1
---------------------------------------------------------------------

- Improving vignette and changing `eval=FALSE` functioning.
- Changing `newline` chunk option to `line.sep`.
- Fixing instructions regarding install with `remotes` to avoid missing vignettes problems.


knitrdata 0.2.0
---------------------------------------------------------------------

- Adding loader.function chunk option

knitrdata 0.1.0
---------------------------------------------------------------------

- Initial release
